==> apache-pinot-0.11.0-src.tar.gz: apache-pinot-0.11.0-src/pinot-query-planner/src/main/java/org/apache/pinot/query/planner/stage/TableScanNode.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.pinot.query.planner.stage;

import java.util.List;
import org.apache.pinot.common.utils.DataSchema;
import org.apache.pinot.query.planner.serde.ProtoProperties;


public class TableScanNode extends AbstractStageNode {
  @ProtoProperties
  private String _tableName;
  @ProtoProperties
  private List<String> _tableScanColumns;

  public TableScanNode(int stageId) {
    super(stageId);
  }

  public TableScanNode(int stageId, DataSchema dataSchema, String tableName, List<String> tableScanColumns) {
    super(stageId, dataSchema);
    _tableName = tableName;
    _tableScanColumns = tableScanColumns;
  }

  public String getTableName() {
    return _tableName;
  }

  public List<String> getTableScanColumns() {
    return _tableScanColumns;
  }
}

==> apache-pinot-0.12.1-src.tar.gz: apache-pinot-0.12.1-src/pinot-query-planner/src/main/java/org/apache/pinot/query/planner/stage/TableScanNode.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.pinot.query.planner.stage;

import java.util.List;
import org.apache.pinot.common.utils.DataSchema;
import org.apache.pinot.query.planner.serde.ProtoProperties;


public class TableScanNode extends AbstractStageNode {
  @ProtoProperties
  private String _tableName;
  @ProtoProperties
  private List<String> _tableScanColumns;

  public TableScanNode(int stageId) {
    super(stageId);
  }

  public TableScanNode(int stageId, DataSchema dataSchema, String tableName, List<String> tableScanColumns) {
    super(stageId, dataSchema);
    _tableName = tableName;
    _tableScanColumns = tableScanColumns;
  }

  public String getTableName() {
    return _tableName;
  }

  public List<String> getTableScanColumns() {
    return _tableScanColumns;
  }

  @Override
  public String explain() {
    return "TABLE SCAN (" + _tableName + ")";
  }

  @Override
  public <T, C> T visit(StageNodeVisitor<T, C> visitor, C context) {
    return visitor.visitTableScan(this, context);
  }
}
